@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ob-chatgpt-shell" "2.0.1"
+(define-package "ob-chatgpt-shell" "20250704.705"
   "Org babel functions for ChatGPT evaluation."
   '((emacs         "27.1")
     (chatgpt-shell "2.24.1"))
